* OOTkinterCanvas

+ An object oriented extended Python/tkinter Canvas window.
+ A pure object oriented architecture for Canvas widgets.
+ New widgets with new functionalities.
+ Support of gif animations.
+ Makes you completely independent from complex concept of tkinter.
+ Support previous usages of tkinter.
+ See the tkinter Python module, Canvas class, for basic functionalities.
+ Usage examples for the "OOTkinterCanvas" class are included in the file "test.py" in this package.